@@ -19,12 +19,13 @@ from Osdental.Shared.Config import Config
 portal_client = PortalClient()
 aes = AES()
 
+
 async def validate_token(token_id: str, user_id: str):
     request = {
         'idToken': token_id,
         'idUser': user_id
     }
-    res = await portal_client.validate_auth_token(request)
+    res = await portal_client.validate_auth_token(json.dumps(request))
     is_auth = int(res.data) == 1
     if res.status != Code.PROCESS_SUCCESS_CODE or not is_auth:
         raise UnauthorizedException(message=Message.PORTAL_ACCESS_RESTRICTED_MSG, error=Message.PORTAL_ACCESS_RESTRICTED_MSG)        
@@ -76,8 +77,9 @@ async def decrypted_token(info: GraphQLResolveInfo = None, legacy: Legacy = None
     if should_use_zero_uuid:
         token.id_external_enterprise = str(UUID(int=0))
     elif should_use_mk_header:
-        token.id_external_enterprise = aes.decrypt(token.aes_key_auth, id_external_mk)
-        token.mk_id_external_enterprise = id_external_mk
+        external_mk = aes.decrypt(token.aes_key_auth, id_external_mk)
+        token.id_external_enterprise = external_mk
+        token.mk_id_external_enterprise = external_mk
 
     return token
 
@@ -102,6 +104,7 @@ def decrypted_data(aes_data: Optional[str], aes_key_auth: str, token: AuthToken)
 
     return data
 
+
 def process_encrypted_data(mutate: bool = True, allowed_permissions: Optional[Union[str, Tuple[str, ...]]] = None):
     def decorator(func: Callable):
         @wraps(func)
