@@ -1,22 +1,8 @@
 from functools import wraps
 from tenacity import retry, stop_after_attempt, wait_exponential, retry_if_exception_type
-from sqlalchemy.exc import OperationalError, DBAPIError
 import grpc
 import httpx
 
-# DB
-def db_retry(func):
-    @retry(
-        stop=stop_after_attempt(3),
-        wait=wait_exponential(multiplier=1, min=1, max=4),
-        retry=retry_if_exception_type((OperationalError, DBAPIError)),
-        reraise=True
-    )
-    @wraps(func)
-    async def wrapper(*args, **kwargs):
-        return await func(*args, **kwargs)
-    return wrapper
-
 
 # gRPC
 def grpc_retry(func):
