@@ -5,9 +5,11 @@ class Code(StrEnum):
     UNAUTHORIZATED_CODE = 'DB_ERROR_0006'
     REQUEST_NOT_COMPLETED_CODE = 'DB_ERROR_9999'
     DATA_NOT_FOUND_CODE = 'DB_ERROR_0404'
-    APP_ERROR_CODE = 'DB_ERROR_APP'
+    APP_ERROR_CODE = 'DB_ERROR_CONTROLLED'
+    UNEXPECTED_ERROR_CODE = 'DB_ERROR_UNEXPECTED'
     INVALID_REQUEST_PARAMS_CODE = 'DB_WARNING_INVALID_REQUEST_PARAMS'
     DATABASE_ERROR_CODE = 'DB_WARNING_DATABASE_ERROR'
+    DATABASE_CONNECTION_ERROR_CODE = 'DB_ERROR_DATABASE_CONNECTION'
     RSA_ERROR_CODE = 'DB_ERROR_RSA'
     AES_ERROR_CODE = 'DB_ERROR_AES'
     JWT_ERROR_CODE = 'DB_ERROR_JWT'
