@@ -9,4 +9,8 @@ class Constant(StrEnum):
     RESPONSE_TYPE_ERROR = 'ERROR'
     RESPONSE_TYPE_REQUEST = 'REQUEST'
     RESPONSE_TYPE_RESPONSE = 'RESPONSE'
-    MESSAGE_LOG_EXTERNAL = 'MESSAGE_LOG_EXTERNAL'
\ No newline at end of file
+    MESSAGE_LOG_EXTERNAL = 'MESSAGE_LOG_EXTERNAL'
+    GRAPHQL_OPERATION_NAME = 'graphql.operationName'
+    GRAPHQL_STATUS = 'graphql.status'
+    GRAPHQL_MESSAGE = 'graphql.message'
+    GRAPHQL_DURATION_MS = 'graphql.duration_ms'
\ No newline at end of file
